@@ -10,26 +10,29 @@
 
 // CGAL
 #include <CGAL/AABB_tree.h> // must be included before kernel
-#include <CGAL/AABB_traits.h>
+#include <CGAL/AABB_traits_3.h>
 #include <CGAL/AABB_face_graph_triangle_primitive.h>
 #include <CGAL/Exact_predicates_inexact_constructions_kernel.h>
-#include <CGAL/Timer.h>
-#include <CGAL/trace.h>
 #include <CGAL/Polyhedron_3.h>
-#include <CGAL/Surface_mesh_default_triangulation_3.h>
-#include <CGAL/make_surface_mesh.h>
-#include <CGAL/Poisson_implicit_surface_3.h>
-#include <CGAL/IO/facets_in_complex_2_to_triangle_mesh.h>
+
+#include <CGAL/Mesh_triangulation_3.h>
+#include <CGAL/Mesh_complex_3_in_triangulation_3.h>
+#include <CGAL/Mesh_criteria_3.h>
+#include <CGAL/Poisson_mesh_domain_3.h>
+#include <CGAL/make_mesh_3.h>
+#include <CGAL/facets_in_complex_3_to_triangle_mesh.h>
+
 #include <CGAL/Poisson_reconstruction_function.h>
-#include <CGAL/IO/read_xyz_points.h>
+#include <CGAL/IO/read_points.h>
 #include <CGAL/compute_average_spacing.h>
 #include <CGAL/Polygon_mesh_processing/compute_normal.h>
 
+#include <CGAL/Timer.h>
+
 #include <deque>
 #include <cstdlib>
 #include <fstream>
 #include <math.h>
-#include <boost/foreach.hpp>
 
 // ----------------------------------------------------------------------------
 // Types
@@ -52,14 +55,15 @@ typedef CGAL::Polyhedron_3<Kernel> Polyhedron;
 // Poisson implicit function
 typedef CGAL::Poisson_reconstruction_function<Kernel> Poisson_reconstruction_function;
 
-// Surface mesher
-typedef CGAL::Surface_mesh_default_triangulation_3 STr;
-typedef CGAL::Surface_mesh_complex_2_in_triangulation_3<STr> C2t3;
-typedef CGAL::Poisson_implicit_surface_3<Kernel, Poisson_reconstruction_function> Surface_3;
+// Mesh_3
+typedef CGAL::Poisson_mesh_domain_3<Kernel> Mesh_domain;
+typedef typename CGAL::Mesh_triangulation_3<Mesh_domain>::type Tr;
+typedef CGAL::Mesh_complex_3_in_triangulation_3<Tr> C3t3;
+typedef CGAL::Mesh_criteria_3<Tr> Mesh_criteria;
 
 // AABB tree
 typedef CGAL::AABB_face_graph_triangle_primitive<Polyhedron> Primitive;
-typedef CGAL::AABB_traits<Kernel, Primitive> AABB_traits;
+typedef CGAL::AABB_traits_3<Kernel, Primitive> AABB_traits;
 typedef CGAL::AABB_tree<AABB_traits> AABB_tree;
 
 struct Counter {
@@ -75,7 +79,7 @@ struct Counter {
       std::cerr << "Counter reached " << N << std::endl;
     }
   }
-  
+
 };
 
 struct InsertVisitor {
@@ -106,19 +110,18 @@ int main(int argc, char * argv[])
     //***************************************
 
     // usage
-    if (argc-1 < 2)
+    if(argc == 1)
     {
       std::cerr << "Reads a point set or a mesh's set of vertices, reconstructs a surface using Poisson,\n";
       std::cerr << "and saves the surface.\n";
       std::cerr << "\n";
-      std::cerr << "Usage: " << argv[0] << " file_in file_out [options]\n";
+      std::cerr << "Usage: " << argv[0] << " [file_in] [file_out] [options]\n";
       std::cerr << "Input file formats are .off (mesh) and .xyz or .pwn (point set).\n";
       std::cerr << "Output file format is .off.\n";
       std::cerr << "Options:\n";
       std::cerr << "  -sm_radius <float>     Radius upper bound (default=100 * average spacing)\n";
       std::cerr << "  -sm_distance <float>   Distance upper bound (default=0.25 * average spacing)\n";
-      
-      return EXIT_FAILURE;
+      std::cerr << "Running " << argv[0] << "data/kitten.xyz kitten_poisson-20-100-0.5.off -sm_distance 0.5\n";
     }
 
     // Poisson options
@@ -130,8 +133,8 @@ int main(int argc, char * argv[])
     double average_spacing_ratio = 5;
 
     // decode parameters
-    std::string input_filename  = argv[1];
-    std::string output_filename = argv[2];
+    std::string input_filename  = (argc > 1) ? argv[1] : CGAL::data_file_path("points_3/kitten.xyz");
+    std::string output_filename = (argc > 2) ? argv[2] : "kitten_poisson-20-100-0.5.off";
     for (int i=3; i+1<argc ; ++i)
     {
       if (std::string(argv[i])=="-sm_radius")
@@ -150,6 +153,8 @@ int main(int argc, char * argv[])
       }
     }
 
+    if (argc == 1) sm_distance = 0.5;
+
     CGAL::Timer task_timer; task_timer.start();
 
     //***************************************
@@ -175,7 +180,7 @@ int main(int argc, char * argv[])
 
       // Converts Polyhedron vertices to point set.
       // Computes vertices normal from connectivity.
-      BOOST_FOREACH(boost::graph_traits<Polyhedron>::vertex_descriptor v,
+      for(boost::graph_traits<Polyhedron>::vertex_descriptor v :
                     vertices(input_mesh)){
         const Point& p = v->point();
         Vector n = CGAL::Polygon_mesh_processing::compute_vertex_normal(v,input_mesh);
@@ -187,18 +192,13 @@ int main(int argc, char * argv[])
              extension == ".pwn" || extension == ".PWN")
     {
       // Reads the point set file in points[].
-      // Note: read_xyz_points_and_normals() requires an iterator over points
+      // Note: read_points() requires an iterator over points
       // + property maps to access each point's position and normal.
-      std::ifstream stream(input_filename.c_str());
-      if (!stream ||
-          !CGAL::read_xyz_points(
-                                stream,
-                                std::back_inserter(points),
-                                CGAL::parameters::point_map
-                                (CGAL::make_first_of_pair_property_map(Point_with_normal())).
-                                normal_map (CGAL::make_second_of_pair_property_map(Point_with_normal()))))
+      if (!CGAL::IO::read_points(input_filename.c_str(), std::back_inserter(points),
+                                  CGAL::parameters::point_map(CGAL::make_first_of_pair_property_map(Point_with_normal()))
+                                                    .normal_map(CGAL::make_second_of_pair_property_map(Point_with_normal()))))
       {
-        std::cerr << "Error: cannot read file " << input_filename << std::endl;
+        std::cerr << "Error: cannot read input file!" << input_filename << std::endl;
         return EXIT_FAILURE;
       }
     }
@@ -234,10 +234,10 @@ int main(int argc, char * argv[])
 
     CGAL::Timer reconstruction_timer; reconstruction_timer.start();
 
-    
+
     Counter counter(std::distance(points.begin(), points.end()));
     InsertVisitor visitor(counter) ;
-    
+
 
     //***************************************
     // Computes implicit function
@@ -260,14 +260,14 @@ int main(int argc, char * argv[])
       {
         std::cerr << "Use Eigen 3\n";
         CGAL::Eigen_solver_traits<Eigen::ConjugateGradient<CGAL::Eigen_sparse_symmetric_matrix<double>::EigenType> > solver;
-        if ( ! function.compute_implicit_function(solver, visitor, 
+        if ( ! function.compute_implicit_function(solver, visitor,
                                                 approximation_ratio,
                                                 average_spacing_ratio) )
         {
           std::cerr << "Error: cannot compute implicit function" << std::endl;
           return EXIT_FAILURE;
         }
-      }    
+      }
       else
       {
         std::cerr << "Error: invalid solver " << solver_name << "\n";
@@ -310,36 +310,33 @@ int main(int argc, char * argv[])
     Sphere bsphere = function.bounding_sphere();
     FT radius = std::sqrt(bsphere.squared_radius());
 
-    // Defines the implicit surface: requires defining a
-  	// conservative bounding sphere centered at inner point.
     FT sm_sphere_radius = 5.0 * radius;
     FT sm_dichotomy_error = sm_distance*average_spacing/1000.0; // Dichotomy error must be << sm_distance
-    Surface_3 surface(function,
-                      Sphere(inner_point,sm_sphere_radius*sm_sphere_radius),
-                      sm_dichotomy_error/sm_sphere_radius);
 
-    // Defines surface mesh generation criteria
-    CGAL::Surface_mesh_default_criteria_3<STr> criteria(sm_angle,  // Min triangle angle (degrees)
-                                                        sm_radius*average_spacing,  // Max triangle size
-                                                        sm_distance*average_spacing); // Approximation error
+    // Defines generation criteria
+    Mesh_criteria criteria(CGAL::parameters::facet_angle = sm_angle,
+                           CGAL::parameters::facet_size = sm_radius*average_spacing,
+                           CGAL::parameters::facet_distance = sm_distance*average_spacing);
 
-    CGAL_TRACE_STREAM << "  make_surface_mesh(sphere center=("<<inner_point << "),\n"
+    std::cerr         << "  make_mesh_3 with sphere center=("<<inner_point << "),\n"
                       << "                    sphere radius="<<sm_sphere_radius<<",\n"
                       << "                    angle="<<sm_angle << " degrees,\n"
                       << "                    triangle size="<<sm_radius<<" * average spacing="<<sm_radius*average_spacing<<",\n"
                       << "                    distance="<<sm_distance<<" * average spacing="<<sm_distance*average_spacing<<",\n"
                       << "                    dichotomy error=distance/"<<sm_distance*average_spacing/sm_dichotomy_error<<",\n"
-                      << "                    Manifold_with_boundary_tag)\n";
+                      << "                    manifold_with_boundary()\n";
 
-    // Generates surface mesh with manifold option
-    STr tr; // 3D Delaunay triangulation for surface mesh generation
-    C2t3 c2t3(tr); // 2D complex in 3D Delaunay triangulation
-    CGAL::make_surface_mesh(c2t3,                                 // reconstructed mesh
-                            surface,                              // implicit surface
-                            criteria,                             // meshing criteria
-                            CGAL::Manifold_with_boundary_tag());  // require manifold mesh
+    // Defines mesh domain
+    Mesh_domain domain = Mesh_domain::create_Poisson_mesh_domain(function, bsphere,
+        CGAL::parameters::relative_error_bound(sm_dichotomy_error / sm_sphere_radius));
+
+    // Generates mesh with manifold option
+    C3t3 c3t3 = CGAL::make_mesh_3<C3t3>(domain, criteria,
+                                        CGAL::parameters::surface_only()
+                                        .manifold_with_boundary());
 
     // Prints status
+    const Tr& tr = c3t3.triangulation();
     std::cerr << "Surface meshing: " << task_timer.time() << " seconds, "
                                      << tr.number_of_vertices() << " output vertices"
                                      << std::endl;
@@ -350,7 +347,7 @@ int main(int argc, char * argv[])
 
     // Converts to polyhedron
     Polyhedron output_mesh;
-    CGAL::facets_in_complex_2_to_triangle_mesh(c2t3, output_mesh);
+    CGAL::facets_in_complex_3_to_triangle_mesh(c3t3, output_mesh);
 
     // Prints total reconstruction duration
     std::cerr << "Total reconstruction (implicit function + meshing): " << reconstruction_timer.time() << " seconds\n";
@@ -362,7 +359,6 @@ int main(int argc, char * argv[])
     // Constructs AABB tree and computes internal KD-tree
     // data structure to accelerate distance queries
     AABB_tree tree(faces(output_mesh).first, faces(output_mesh).second, output_mesh);
-    tree.accelerate_distance_queries();
 
     // Computes distance from each input point to reconstructed mesh
     double max_distance = DBL_MIN;
