@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0.3/Circular_kernel_3/include/CGAL/Circular_kernel_3/Line_arc_3.h $
-// $Id: include/CGAL/Circular_kernel_3/Line_arc_3.h cefe3007d59 $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Circular_kernel_3/include/CGAL/Circular_kernel_3/Line_arc_3.h $
+// $Id: include/CGAL/Circular_kernel_3/Line_arc_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s) : Monique Teillaud, Sylvain Pion, Pedro Machado,
@@ -168,7 +168,7 @@ namespace CGAL {
         return begin_less_xyz_than_end() ? target() : source();
       }
 
-      const CGAL::Bbox_3 bbox() const {
+      CGAL::Bbox_3 bbox() const {
         return source().bbox() + target().bbox();
       }
 
