@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0/Heat_method_3/include/CGAL/Heat_method_3/internal/Intrinsic_Delaunay_triangulation_3.h $
-// $Id: include/CGAL/Heat_method_3/internal/Intrinsic_Delaunay_triangulation_3.h 50219fc33bc $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Heat_method_3/include/CGAL/Heat_method_3/internal/Intrinsic_Delaunay_triangulation_3.h $
+// $Id: include/CGAL/Heat_method_3/internal/Intrinsic_Delaunay_triangulation_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -446,7 +446,7 @@ private:
     for(face_descriptor f : faces(m_intrinsic_tm)) {
       CGAL::Vertex_around_face_iterator<TriangleMesh> vbegin, vend, vmiddle;
 
-      boost::tie(vbegin, vend) = vertices_around_face(halfedge(f,m_intrinsic_tm),m_intrinsic_tm);
+      std::tie(vbegin, vend) = vertices_around_face(halfedge(f,m_intrinsic_tm),m_intrinsic_tm);
       halfedge_descriptor hd = halfedge(f,m_intrinsic_tm);
       if(face(hd,m_intrinsic_tm) != f) {
         hd = opposite(hd,m_intrinsic_tm);
