@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Intersections_3/include/CGAL/Intersections_3/internal/Plane_3_Plane_3_Plane_3_intersection.h $
-// $Id: Plane_3_Plane_3_Plane_3_intersection.h 6dca71b4283 2023-12-07T10:19:36+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Intersections_3/include/CGAL/Intersections_3/internal/Plane_3_Plane_3_Plane_3_intersection.h $
+// $Id: include/CGAL/Intersections_3/internal/Plane_3_Plane_3_Plane_3_intersection.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -18,8 +18,8 @@
 #include <CGAL/Intersections_3/internal/Plane_3_Plane_3_intersection.h>
 #include <CGAL/Intersections_3/internal/Line_3_Plane_3_intersection.h>
 
-#include <boost/optional.hpp>
-#include <boost/variant.hpp>
+#include <optional>
+#include <variant>
 
 namespace CGAL {
 namespace Intersections {
@@ -27,7 +27,7 @@ namespace internal {
 
 //  triple plane intersection
 template <class K>
-boost::optional<typename K::Point_3>
+std::optional<typename K::Point_3>
 intersection_point(const typename K::Plane_3& plane1,
                    const typename K::Plane_3& plane2,
                    const typename K::Plane_3& plane3,
@@ -56,7 +56,7 @@ intersection_point(const typename K::Plane_3& plane1,
   const FT den = minor_0*m22 - minor_1*m12 + minor_2*m02; // determinant of M
 
   if(is_zero(den)){
-    return boost::none;
+    return std::nullopt;
   }
 
   const FT num3 = minor_0*b2 - minor_1*b1 + minor_2*b0;  // determinant of M with M[x:2] swapped with [b0,b1,b2]
@@ -70,17 +70,17 @@ intersection_point(const typename K::Plane_3& plane1,
   const FT num1 = - minor_3*m21 + minor_4*m11 - minor_5*m01;  // determinant of M with M[x:0] swapped with [b0,b1,b2]
   const FT num2 = minor_3*m20 - minor_4*m10 + minor_5*m00;  // determinant of M with M[x:1] swapped with [b0,b1,b2]
 
-  return boost::make_optional(typename K::Point_3(num1/den, num2/den, num3/den));
+  return std::make_optional(typename K::Point_3(num1/den, num2/den, num3/den));
 }
 
 template <class K>
-boost::optional<boost::variant<typename K::Point_3, typename K::Line_3, typename K::Plane_3> >
+std::optional<std::variant<typename K::Point_3, typename K::Line_3, typename K::Plane_3> >
 intersection(const typename K::Plane_3& plane1,
              const typename K::Plane_3& plane2,
              const typename K::Plane_3& plane3,
              const K& k)
 {
-  typedef typename boost::optional<boost::variant<typename K::Point_3,
+  typedef typename std::optional<std::variant<typename K::Point_3,
                                                   typename K::Line_3,
                                                   typename K::Plane_3> > result_type;
 
