@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org).
 //
-// $URL: https://github.com/CGAL/cgal/blob/v6.0/Periodic_3_triangulation_3/include/CGAL/Periodic_3_triangulation_3/internal/Periodic_3_triangulation_filtered_traits_3.h $
-// $Id: include/CGAL/Periodic_3_triangulation_3/internal/Periodic_3_triangulation_filtered_traits_3.h 50219fc33bc $
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Periodic_3_triangulation_3/include/CGAL/Periodic_3_triangulation_3/internal/Periodic_3_triangulation_filtered_traits_3.h $
+// $Id: include/CGAL/Periodic_3_triangulation_3/internal/Periodic_3_triangulation_filtered_traits_3.h b26b07a1242 $
 // SPDX-License-Identifier: GPL-3.0-or-later OR LicenseRef-Commercial
 //
 // Author(s)     : Sylvain Pion <Sylvain.Pion@sophia.inria.fr>
@@ -52,7 +52,7 @@ struct Offset_converter_3
 
   using Base::operator();
 
-  Target_off
+  const Target_off&
   operator()(const Source_off &off) const
   {
     return off;
@@ -106,6 +106,24 @@ public:
     traits_f.set_domain(C2F()(domain));
   }
 
+  typedef Filtered_predicate<
+            typename Exact_traits::Compare_x_3,
+            typename Filtering_traits::Compare_x_3,
+            Offset_converter_3<C2E>,
+            Offset_converter_3<C2F> >  Compare_x_3;
+
+  typedef Filtered_predicate<
+            typename Exact_traits::Compare_y_3,
+            typename Filtering_traits::Compare_y_3,
+            Offset_converter_3<C2E>,
+            Offset_converter_3<C2F> >  Compare_y_3;
+
+  typedef Filtered_predicate<
+            typename Exact_traits::Compare_z_3,
+            typename Filtering_traits::Compare_z_3,
+            Offset_converter_3<C2E>,
+            Offset_converter_3<C2F> >  Compare_z_3;
+
   typedef Filtered_predicate<
             typename Exact_traits::Compare_xyz_3,
             typename Filtering_traits::Compare_xyz_3,
@@ -118,6 +136,30 @@ public:
             Offset_converter_3<C2E>,
             Offset_converter_3<C2F> >  Orientation_3;
 
+  Compare_x_3 compare_x_3_object() const
+  {
+    typename Exact_traits::Compare_x_3 pe = traits_e.compare_x_3_object();
+    typename Filtering_traits::Compare_x_3 pf = traits_f.compare_x_3_object();
+
+    return Compare_x_3(pe, pf);
+  }
+
+  Compare_y_3 compare_y_3_object() const
+  {
+    typename Exact_traits::Compare_y_3 pe = traits_e.compare_y_3_object();
+    typename Filtering_traits::Compare_y_3 pf = traits_f.compare_y_3_object();
+
+    return Compare_y_3(pe, pf);
+  }
+
+  Compare_z_3 compare_z_3_object() const
+  {
+    typename Exact_traits::Compare_z_3 pe = traits_e.compare_z_3_object();
+    typename Filtering_traits::Compare_z_3 pf = traits_f.compare_z_3_object();
+
+    return Compare_z_3(pe, pf);
+  }
+
   Compare_xyz_3 compare_xyz_3_object() const
   {
     typename Exact_traits::Compare_xyz_3 pe = traits_e.compare_xyz_3_object();
