@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.6.3/Number_types/include/CGAL/Sqrt_extension/Sqrt_extension_type.h $
-// $Id: Sqrt_extension_type.h 058ce7c76a1 2023-03-16T13:52:56+01:00 Andreas Fabri
+// $URL: https://github.com/CGAL/cgal/blob/v6.1/Number_types/include/CGAL/Sqrt_extension/Sqrt_extension_type.h $
+// $Id: include/CGAL/Sqrt_extension/Sqrt_extension_type.h b26b07a1242 $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -32,7 +32,7 @@
 #include <boost/operators.hpp>
 #include <CGAL/Interval_arithmetic.h>
 #include <CGAL/Sqrt_extension_fwd.h>
-#include <boost/optional.hpp>
+#include <optional>
 #include <CGAL/NT_converter.h>
 
 #include <type_traits>
@@ -92,7 +92,7 @@ template <>
 class Interval_optional_caching< ::CGAL::Tag_true >
 {
 protected:
-  typedef boost::optional< std::pair<double,double> > Cached_interval;
+  typedef std::optional< std::pair<double,double> > Cached_interval;
   mutable Cached_interval interval_;
   void invalidate_interval() {interval_=Cached_interval();}
   bool is_cached() const {return (interval_?true:false);}
@@ -135,6 +135,31 @@ public:
     Sqrt_extension(const NT& i)
         : a0_(NT(i)), a1_(NT(0)), root_(ROOT(0)), is_extended_(false) {}
 
+    Sqrt_extension(const Sqrt_extension<NT, ROOT_, ACDE_TAG, std::integral_constant<bool, !FP_TAG::value>>& other)
+        : a0_(other.a0()), a1_(other.a1()), root_(other.root()), is_extended_(other.is_extended())
+    {}
+
+    Sqrt_extension&
+    operator=(const Sqrt_extension<NT, ROOT_, ACDE_TAG, std::integral_constant<bool,!FP_TAG::value>>& other)
+    {
+      *this = Sqrt_extension(other);
+      return *this;
+    }
+
+    Sqrt_extension&
+    operator=(const NT& i)
+    {
+      *this = Sqrt_extension(i);
+      return *this;
+    }
+
+    Sqrt_extension&
+    operator=(CGAL_int(NT) i)
+    {
+      *this = Sqrt_extension(i);
+      return *this;
+    }
+
     //non-documented: used for Make_sqrt
     Sqrt_extension(const ROOT& root,bool)
           :a0_(NT(0)), a1_(NT(1)), root_(root), is_extended_(true) {}
@@ -178,10 +203,10 @@ public:
      */
   template <class NTX>
   explicit Sqrt_extension(const NTX& a, const NTX& b, const NTX& c, const bool is_smaller,
-    std::enable_if_t< boost::mpl::and_<
-      std::is_same< typename Fraction_traits<NT>::Numerator_type,NTX >,
-      std::is_same< typename Fraction_traits<ROOT>::Numerator_type,NTX >
-    >::value >* = 0  )
+    std::enable_if_t<
+      std::is_same_v< typename Fraction_traits<NT>::Numerator_type,NTX > &&
+      std::is_same_v< typename Fraction_traits<ROOT>::Numerator_type,NTX >
+    >* = 0  )
   {
     typename Fraction_traits<NT>::Compose compose_nt;
     typename Fraction_traits<ROOT>::Compose compose_root;
